==> base-config_0.33.2.tar.gz: base-config/apt-setup.templates.pl <==
Template: apt-setup/uri_type
Type: select
Choices: cdrom, http, ftp, filesystem, edit sources list by hand
Default: cdrom
Description: Choose the method apt should use to access the Debian archive:
 Apt can access the Debian archive in a variety of ways. Choose the access
 method apt should use. For example if you have a Debian cd, select "cdrom",
 while if you plan to install via a Debian mirror, choose "ftp" or "http".
 .
 ${note}
Choices-pl: cdrom, http, ftp, system plikw, rczna edycja list
Description-pl: Wybierz metod dostpu do archiww Debiana ktrej powinien uy apt:
 Apt moe uzyska dostp do archiww Debiana na wiele sposobw. Wybierz
 metod, ktrej chesz uywa. Jeli masz na przykad CDROM z Debianem,
 wybierz "cdrom", jeli planujesz instalacj z serwera lustrzanego, wybierz
 "ftp" lub "http".
 .
 ${note}

Template: apt-setup/country
Type: select
Choices: ${countries}
Default: United States
Description: Select a country:
 Select the country the mirror should be in. The goal is to find a mirror that
 is close to you on the network -- be aware that near countries, or even
 your own, may not be the best choice.
Description-pl: Wybierz kraj:
 Wybierz kraj, w ktrym znajduje si serwer lustrzany. Chodzi o to, aby
 znale serwer, ktry jest w podsieci najbliej Ciebie. Zwr uwag, e
 bliskie kraje, a czasem nawet Twj -- nie s najlepszym wyborem. Naley
 wybra ten, z ktrym komunikacja jest najszybsza.

Template: apt-setup/mirror
Type: select
Choices: ${mirrors}
Default: http.us.debian.org
Description: Choose the Debian mirror to use:
 Select the Debian mirror apt should use. You should select a mirror that
 is close to you on the net.
Description-pl: Wybierz serwer lustrzany Debiana:
 Wybierz serwer, ktrego ma uy apt. Powiniene/powinna uy serwera, z
 ktrym komunikacja jest najszybsza.

Template: apt-setup/hostname
Type: string
Description: Enter mirror hostname:
 Enter the hostname of the Debian mirror you want to use.
Description-pl: Wprowad nazw serwera:
 Wprowad nazw serwera (hostname), ktrego chcesz uy.

Template: apt-setup/directory
Type: string
Default: /debian
Description: Enter mirror directory:
 Enter the directory the Debian mirror is located in.
Description-pl: Wprowad katalog:
 Wprowad katalog, w ktrym znajduje si kopia archiwum Debiana.

Template: apt-setup/baddir
Type: note
Description: Mirror not found.
 The directory you entered does not exist.
Description-pl: Nie znaleziono archiwum.
 Podany przez Ciebie katalog nie istnieje.

Template: apt-setup/not-mirror
Type: note
Description: Mirror not found.
 The directory you entered does not contain a subdirectory named "dists",
 so it doesn't seem to be a Debian mirror.
Description-pl: Nie znaleziono archiwum.
 Podany przez Ciebie katalog nie zawiera podkatalogu o nazwie "dists", wic
 nie wyglda na archiwum Debiana.

Template: apt-setup/cd/dev
Type: string
Description: Enter CD ROM device file:
 This program was unable to auto-detect a CD ROM drive, or there is no
 usable CD in the drive. Enter the device file to use to access your CD
 ROM, and place a Debian CD in the drive.
Description-pl: Wprowad nazw pliku urzdzenia CDROM:
 Nie udao si wykry napdu CD, lub w napdzie nie ma potrzebnej pyty.
 Wprowad nazw pliku urzdzenia CDROM i w pyt Debiana do napdu.

Template: apt-setup/cd/bad
Type: note
Description: Bad CD
 Your CD drive was detected, but it does not seem to have a Debian CD in it.
Description-pl: Niewaciwa pyta
 Twj napd CD zosta wykryty, ale nie zawiera pyty Debiana.

Template: apt-setup/cd/another
Type: boolean
Default: false
Description: Scan another CD?
 If you have another Debian CD (for example, the second in a two CD set),
 you should insert and scan it now.
Description-pl: Czy sprawdzi nastpn pyt?
 Jeli masz jeszcze jak pyt Debiana (na przykad drug z zestawu),
 powiniene/powinna j teraz woy.

Template: apt-setup/non-free
Type: boolean
Default: false
Description: Use non-free software?
 Some non-free software has been made to work with Debian. Though this
 software is not at all a part of Debian, standard Debian tools can be
 used to install it. This software has varying licenses which may prevent
 you from using, modifying, or sharing it. Do you want to have it
 available anyway?
Description-pl: Czy uywa oprogramowania nie wolnodostpnego?
 wiono dziaanie w Debianie rnych niewolnodostpnych programw. Cho
 nie s one w adnym przypadku czci Debiana, standardowe narzdzia
 Debiana umoliwiaj ich instalacj. Programy te maj rne licencje, ktre
 mog uniemoliwi Ci ich uywanie, modyfikacj lub rozprowadzanie. Czy mimo
 to chcesz mie do nich dostp?

Template: apt-setup/non-us
Type: boolean
Default: true
Description: Use non-US software?
 Some software in Debian must be downloaded from sites outside the United
 States. This includes some cryptographic software, and some software with
 patent problems in the US. Do you want this software to be made available
 to you?
Description-pl: Czy uywa oprogramowania non-US?
 Niektre programy Debiana musz zosta sprowadzone z serwerw spoza USA.
 Obejmuje to oprogramowanie kryptograficzne i niektre programy z problemami
 patentowymi w USA. Czy chcesz mie moliwo instalacji takiego
 oprogramowania?

Template: apt-setup/contrib
Type: boolean
Default: false
Description: Use contrib software?
 Some additional software has been made to work with Debian. Though this
 software is free, it depends on non-free software for its operation.
 This software is not at all a part of Debian, but standard Debian
 tools can be used to install it. Would you like to have it available?
Description-pl: Czy uywa oprogramowania "contrib"?
 Umoliwiono dziaanie w Debianie rnych dodatkowych programw. Cho s one
 wolnodostpne, wymagaj do dziaania oprogramowania niewolnodostpnego.
 Cho nie s one w adnym przypadku czci Debiana, standardowe narzdzia
 Debiana umoliwiaj ich instalacj. Czy mimo to chcesz mie do nich dostp?

Template: apt-setup/distribution
Type: select
Choices: stable, unstable, potato
Default: potato
Description: Select Debian distribution to use:
 Debian comes in two flavors. Stable is well-tested and rarely changes.
 Unstable is untested and frequently changing. Which of the two do you wish
 to install?
 .
 While Debian is frozen, it is best to select "potato", which will be
 turning into Debian stable real soon now.
Choices-pl: stabilna, niestabilna, potato
Description-pl: Wybierz dystrybucj do zainstalowania
 S dwie wersje Debiana. Stabilna jest dokadnie sprawdzona i rzadko si
 zmienia. Niestabilna nie jest sprawdzona i zmienia si czsto. Ktr z nich
 chcesz zainstalowa?
 .
 W czasie, gdy Debian jest zamroony, najlepiej jest wybra "potato", ktra
 wkrtce stanie si stabilna.

Template: apt-setup/badsource
Type: note
Description: Failed to access the Debian archive
 When I tried to access the debian archive using the information you
 provided, apt gave the following error. I will run through the
 questions again, try to correct the error.
 .
 ${apt_error}
Description-pl: Prba dostpu do archiwum nie powioda si
 Podczas prby dostpu do archiwum, ktrego dane zostay podane, apt zwrci
 nastpujcy bd. Jeszcze raz zostan zadane wszystkie pytania, co by moe
 pozwoli naprawi problem.
 .
 ${apt_error}

Template: apt-setup/another
Type: boolean
Default: false
Description: Add another apt source?
 Apt is now configured, and should be able to install Debian packages.
 However, you may want to add another source to apt, so it can download
 packages from more than one location.
Description-pl: Doda jeszcze jedno rdo dla apt-a?
 Apt zosta skonfigurowany, i powinien by w stanie zainstalowa pakiety
 Debiana. Jednak moesz doda jeszcze jedno rdo, aby by w stanie
 sprowadza pakiety z wicej ni jednego miejsca.

Template: apt-setup/badedit
Type: select
Choices: edit, revert to backup
Description: What do you want to do?
 The entries you made in sources.list did not work. Here is the error message
 from apt:
 .
 ${apt_error}
 .
 I have a backup of the sources.list from before you edited it. Should I
 revert to that backup, or would you like to edit the existing file and
 fix it?
Choices-pl: modyfikuj, wr do kopii zapasowej
Description-pl: Co chcesz zrobi?
 Utworzony przez Ciebie plik sources.list nie zadziaa. Oto komunikat bdu
 zwrcony przez apt-a:
 .
 ${apt_error}
 .
 Zanim zmienie/zmienia plik sources.list, zostaa utworzona kopia
 zapasowa. Czy ma zosta przywrcona ta kopia, czy chcesz poprawi istniejcy
 plik?

Template: apt-setup/non-us-failed
Type: note
Description: Cannot access non-US software.
 I cannot access the Debian archive site that contains non-US software, so
 that software will not be made available to you. The error message I
 received from apt was:
 .
 ${apt_error}
Description-pl: Nie mona uzyska dostpu do oprogramowania non-US.
 Nie udao si uzyska dostpu do serwera zawierajcego oprogramowanie
 non-US, wic nie bdzie ono dostpne. Apt zwrci nastpujcy bd:
 .
 ${apt_error}

Template: apt-setup/http_proxy
Type: string
Description: Enter http proxy information, or leave blank for none:
 If you need to use a http proxy to access the outside world, enter the
 proxy information here. Otherwise, leave this blank.
 .
 When entering proxy information, use the standard form of
 "http://[[user][:pass]@]host[:port]/"
Description-pl: Wpisz informacj dotyczc proxy, lub zostaw pole puste:
 Jeli korzystasz z http proxy, wpisz dotyczc go informacj tutaj. W
 przeciwnym wypadku, zostaw to pole puste.
 .
 Uyj formy
 "http://[[uytkownik][:haso]@]serwer[:port]/"

Template: apt-setup/security-updates
Type: boolean
Default: true
Description: Use security updates from security.debian.org?
 Debian provides timely security updates via the website
 http://security.debian.org/ . Should these updates be tracked each time
 you upgrade your system? If you are on the internet, this is generally a
 good idea.
Description-pl: Czy uywa uaktualnie z security.debian.org?
 Debian umoliwia pobieranie uaktualnie dotyczcych bezpieczestwa ze
 strony http://security.debian.org/ . Czy te uaktualnienia powinny by
 instalowane przy kadej aktualizacji systemu? Jeli posiadasz szybkie cze
 z Internetem, jest to zazwyczaj dobry pomys.

Template: apt-setup/security-updates-failed
Type: note
Description: Cannot access security updates.
 I cannot access the security updates on security.debian.org, so
 those updates will not be made available to you at this time.
 You may want to invesitgate this later.. Commented out entries
 for security.debian.org have been added to the bottom of
 /etc/apt/sources.list . The error message I received from apt was:
 .
 ${apt_error}
Description-pl: Nie da si uzyska dostpu do uaktualnie dotyczcych bezpieczestwa.
 Nie da si uzyska dostpu do uaktualnie dotyczcych bezpieczestwa na
 serwerze security.debian.org, wic w tym momencie uaktualnienia te nie bd
 dostpne. Moesz pniej to sprawdzi. Wykomentowane pozycje dotyczce
 security.debian.org zostay dodane na kocu pliku /etc/apt/sources.list . 
 Komunikat bdu uzyskany od programu apt brzmia:
 .
 ${apt_error}

==> base-config_1.33.18.tar.gz: base-config/apt-setup.templates.pl <==
Template: apt-setup/uri_type
Type: select
Choices: cdrom, http, ftp, filesystem, edit sources list by hand
Choices-pl: cdrom, http, ftp, system plikw, rczna edycja list
Default: cdrom
Description: Choose the method apt should use to access the Debian archive:
 Apt can access the Debian archive in a variety of ways. Choose the access
 method apt should use. For example if you have a Debian cd, select
 "cdrom", while if you plan to install via a Debian mirror, choose "ftp" or
 "http".  
 .
 ${note}  
Description-pl: Wybierz metod dostpu do archiww Debiana ktrej powinien uy apt:
 Apt moe uzyska dostp do archiww Debiana na wiele sposobw. Wybierz
 metod, ktrej chesz uywa. Jeli masz na przykad CDROM z Debianem,
 wybierz "cdrom", jeli planujesz instalacj z serwera lustrzanego, wybierz
 "ftp" lub "http". 
 .
 ${note} 

Template: apt-setup/country
Type: select
Choices: ${countries}
Choices-pl: ${countries}
Default: United States
Description: Select a country:
 Select the country the mirror should be in. The goal is to find a mirror
 that is close to you on the network -- be aware that near countries, or
 even your own, may not be the best choice.  
Description-pl: Wybierz kraj:
 Wybierz kraj, w ktrym znajduje si serwer lustrzany. Chodzi o to, aby
 znale serwer, ktry jest w podsieci najbliej Ciebie. Zwr uwag, e
 bliskie kraje, a czasem nawet Twj -- nie s najlepszym wyborem. Naley
 wybra ten, z ktrym komunikacja jest najszybsza. 

Template: apt-setup/mirror
Type: select
Choices: ${mirrors}
Choices-pl: ${mirrors}
Default: http.us.debian.org
Description: Choose the Debian mirror to use:
 Select the Debian mirror apt should use. You should select a mirror that
 is close to you on the net.  
Description-pl: Wybierz serwer lustrzany Debiana:
 Wybierz serwer, ktrego ma uy apt. Powiniene/powinna uy serwera, z
 ktrym komunikacja jest najszybsza. 

Template: apt-setup/hostname
Type: string
Description: Enter mirror hostname:
 Enter the hostname of the Debian mirror you want to use.  
Description-pl: Wprowad nazw serwera:
 Wprowad nazw serwera (hostname), ktrego chcesz uy. 

Template: apt-setup/directory
Type: string
Default: /debian
Default-pl: /debian
Description: Enter mirror directory:
 Enter the directory the Debian mirror is located in.  
Description-pl: Wprowad katalog:
 Wprowad katalog, w ktrym znajduje si kopia archiwum Debiana. 

Template: apt-setup/baddir
Type: note
Description: Mirror not found.
 The directory you entered does not exist.  
Description-pl: Nie znaleziono archiwum.
 Podany przez Ciebie katalog nie istnieje. 

Template: apt-setup/not-mirror
Type: note
Description: Mirror not found.
 The directory you entered does not contain a subdirectory named "dists",
 so it doesn't seem to be a Debian mirror.  
Description-pl: Nie znaleziono archiwum.
 Podany przez Ciebie katalog nie zawiera podkatalogu o nazwie "dists", wic
 nie wyglda na archiwum Debiana. 

Template: apt-setup/cd/dev
Type: string
Description: Enter CD ROM device file:
 This program was unable to auto-detect a CD ROM drive, or there is no
 usable CD in the drive. Enter the device file to use to access your CD
 ROM, and place a Debian CD in the drive.  
Description-pl: Wprowad nazw pliku urzdzenia CDROM:
 Nie udao si wykry napdu CD, lub w napdzie nie ma potrzebnej pyty.
 Wprowad nazw pliku urzdzenia CDROM i w pyt Debiana do napdu. 

Template: apt-setup/cd/bad
Type: note
Description: Bad CD
 Your CD drive was detected, but it does not seem to have a Debian CD in
 it.  
Description-pl: Niewaciwa pyta
 Twj napd CD zosta wykryty, ale nie zawiera pyty Debiana. 

Template: apt-setup/cd/another
Type: boolean
Default: false
Description: Scan another CD?
 If you have another Debian CD (for example, the second in a two CD set),
 you should insert and scan it now.  
Description-pl: Czy sprawdzi nastpn pyt?
 Jeli masz jeszcze jak pyt Debiana (na przykad drug z zestawu),
 powiniene/powinna j teraz woy. 

Template: apt-setup/non-free
Type: boolean
Default: false
Description: Use non-free software?
 Some non-free software has been made to work with Debian. Though this
 software is not at all a part of Debian, standard Debian tools can be 
 used to install it. This software has varying licenses which may prevent
 you from using, modifying, or sharing it. Do you want to have it available
 anyway? 
Description-pl: Czy uywa oprogramowania nie wolnodostpnego?
 Do dziaania w systemie Debian przystosowano rne programy, ktre
 nie s wolnodostpne. Cho nie s one w adnym przypadku czci Debiana,
 standardowe narzdzia Debiana umoliwiaj ich instalacj. Programy te maj
 rne licencje, ktre mog uniemoliwi Ci ich uywanie, modyfikacj
 lub rozprowadzanie. Czy mimo to chcesz mie do nich dostp? 

Template: apt-setup/non-us
Type: boolean
Default: true
Description: Use non-US software?
 Some software in Debian must be downloaded from sites outside the United
 States. This includes some cryptographic software, and some software with
 patent problems in the US. Do you want this software to be made available
 to you?  
Description-pl: Czy uywa oprogramowania non-US?
 Niektre programy Debiana musz zosta sprowadzone z serwerw spoza USA.
 Obejmuje to oprogramowanie kryptograficzne i niektre programy z
 problemami patentowymi w USA. Czy chcesz mie moliwo instalacji takiego
 oprogramowania? 

Template: apt-setup/contrib
Type: boolean
Default: false
Description: Use contrib software?
 Some additional software has been made to work with Debian. Though this
 software is free, it depends on non-free software for its operation. This
 software is not at all a part of Debian, but standard Debian  tools can be
 used to install it. Would you like to have it available? 
Description-pl: Czy uywa oprogramowania "contrib"?
 Do dziaania w systemie Debian przystosowano rne dodatkowe programy.
 Cho s one wolnodostpne, wymagaj do dziaania oprogramowania
 niewolnodostpnego. Cho nie s one w adnym przypadku czci Debiana,
 standardowe narzdzia Debiana umoliwiaj ich instalacj. Czy mimo to
 chcesz mie do nich dostp? 

Template: apt-setup/distribution
Type: select
Choices: stable, unstable, testing
Choices-pl: stabilna, niestabilna, testowa
Default: stable
Description: Select Debian distribution to use:
 Debian comes in several flavors. Stable is well-tested and rarely changes.
 Unstable is untested and frequently changing. Testing is a middle ground,
 that receives many of the new versions from unstable if they are not too
 buggy. Which version of Debian do you wish to install? 
Description-pl: Wybierz dystrybucj do zainstalowania:
 Jest kilka wersji Debiana. Stabilna jest dokadnie sprawdzona i rzadko si
 zmienia. Niestabilna nie jest sprawdzona i zmienia si czsto. Testowa jest
 czym porodku - zawiera wiele nowych wersji pakietw z dystrybucji
 niestabilnej, ktre nie zawieraj powanych bdw. Ktr z nich chcesz
 zainstalowa?

Template: apt-setup/badsource
Type: note
Description: Failed to access the Debian archive
 When I tried to access the debian archive using the information you
 provided, apt gave the following error. I will run through the questions
 again, try to correct the error.  
 .
 ${apt_error}  
Description-pl: Prba dostpu do archiwum nie powioda si
 Podczas prby dostpu do archiwum, ktrego dane zostay podane, apt
 zwrci nastpujcy bd. Jeszcze raz zostan zadane wszystkie pytania, co
 by moe pozwoli naprawi problem. 
 .
 ${apt_error} 

Template: apt-setup/another
Type: boolean
Default: false
Description: Add another apt source?
 Apt is now configured, and should be able to install Debian packages.
 However, you may want to add another source to apt, so it can download
 packages from more than one location. 
Description-pl: Doda jeszcze jedno rdo dla apt-a?
 Apt zosta skonfigurowany, i powinien by w stanie zainstalowa pakiety
 Debiana. Jednak moesz doda jeszcze jedno rdo, aby by w stanie
 sprowadza pakiety z wicej ni jednego miejsca. 

Template: apt-setup/badedit
Type: select
Choices: edit, revert to backup
Choices-pl: modyfikuj, wr do kopii zapasowej
Description: What do you want to do?
 The entries you made in sources.list did not work. Here is the error
 message from apt:  
 .
 ${apt_error}  
 .
 I have a backup of the sources.list from before you edited it. Should I
 revert to that backup, or would you like to edit the existing file and fix
 it?  
Description-pl: Co chcesz zrobi?
 Utworzony przez Ciebie plik sources.list nie zadziaa. Oto komunikat
 bdu zwrcony przez apt-a: 
 .
 ${apt_error} 
 .
 Zanim zmienie/zmienia plik sources.list, zostaa utworzona kopia
 zapasowa. Czy ma zosta przywrcona ta kopia, czy chcesz poprawi
 istniejcy plik? 

Template: apt-setup/non-us-failed
Type: note
Description: Cannot access non-US software.
 I cannot access the Debian archive site that contains non-US software, so
 that software will not be made available to you. The error message I
 received from apt was:  
 .
 ${apt_error}  
Description-pl: Nie mona uzyska dostpu do oprogramowania non-US.
 Nie udao si uzyska dostpu do serwera zawierajcego oprogramowanie
 non-US, wic nie bdzie ono dostpne. Apt zwrci nastpujcy bd: 
 .
 ${apt_error} 

Template: apt-setup/http_proxy
Type: string
Description: Enter http proxy information, or leave blank for none:
 If you need to use a http proxy to access the outside world, enter the
 proxy information here. Otherwise, leave this blank.  
 .
 When entering proxy information, use the standard form of
 "http://[[user][:pass]@]host[:port]" 
Description-pl: Wpisz informacj dotyczc proxy, lub zostaw pole puste:
 Jeli korzystasz z http proxy, wpisz dotyczc go informacj tutaj. W
 przeciwnym wypadku, zostaw to pole puste. 
 .
 Uyj formy "http://[[uytkownik][:haso]@]serwer[:port]" 

Template: apt-setup/security-updates
Type: boolean
Default: true
Description: Use security updates from security.debian.org?
 Debian provides timely security updates via the website
 http://security.debian.org/ . Should these updates be tracked each time
 you upgrade your system? If you are on the internet, this is generally a
 good idea. 
Description-pl: Czy uywa uaktualnie z security.debian.org?
 Debian umoliwia pobieranie uaktualnie dotyczcych bezpieczestwa ze
 strony http://security.debian.org/ . Czy te uaktualnienia powinny by
 instalowane przy kadej aktualizacji systemu? Jeli posiadasz szybkie
 cze z Internetem, jest to zazwyczaj dobry pomys. 

Template: apt-setup/security-updates-failed
Type: note
Description: Cannot access security updates.
 I cannot access the security updates on security.debian.org, so those
 updates will not be made available to you at this time. You may want to
 invesitgate this later.. Commented out entries for security.debian.org
 have been added to the bottom of /etc/apt/sources.list . The error message
 I received from apt was: 
 .
 ${apt_error} 
Description-pl: Nie da si uzyska dostpu do uaktualnie dotyczcych bezpieczestwa.
 Nie da si uzyska dostpu do uaktualnie dotyczcych bezpieczestwa na
 serwerze security.debian.org, wic w tym momencie uaktualnienia te nie
 bd dostpne. Moesz pniej to sprawdzi. Wykomentowane pozycje
 dotyczce security.debian.org zostay dodane na kocu pliku
 /etc/apt/sources.list .  Komunikat bdu uzyskany od programu apt brzmia:
 .
 ${apt_error}
